Monty Python's Flying Circus: Just the Words - Episode 1

# Episode One: Whither Canada?

It's Wolfgang Amadeus Mozart
Famous deaths
Italian lesson
Whizzo butter
It's the Arts
Arthur 'Two-Sheds' Jackson
Picasso/cycling race
The funniest joke in the world

Colour code: John Cleese - Michael Palin - Eric Idle - Graham Chapman - Terry Jones - Terry Gilliam - Carol Cleveland

| A seashore. Some way out to sea a ragged man is struggling his way to shore. Slowly and with difficulty he makes his way up onto the beach, flops down exhausted and announces:
It's Man | It's...
Voice Over | Monty Python's Flying Circus.
| Titles beginning with words "Monty Python's Flying Circus". Various bizarre things happen. When titles end: Ordinary grey-suited announcer standing by desk. He smiles confidently.
Announcer | Good evening.
| The announcer confidently moves to chair and sits down. There is a squeal as of a pig being sat upon. Cut to a blackboard with several lines of pigs drawn on it in colour. A man steps into view and with a piece of chalk crosses out one of the pigs CAPTION: 'IT'S WOLFGANG AMADEUS MOZART' Mozart sitting at piano tinkling with the keys. He finishes tinkling.
Mozart | Hello again, and welcome to the show. Tonight we continue to look at some famous deaths. Tonight we start with the wonderful death of Genghis Khan, conqueror of India. Take it away Genghis.
| Cut to Genghis Khan's tent. Genghis strides about purposefully. Indian-style background music. Suddenly the music cuts out and Genghis Khan with a squawk throws himself in the air and lands on his back. This happens very suddenly. Judges hold up cards with points on, in the manner of ice skating judges.
Voice Over | 9.1, 9.3, 9.7, that's 28.1 for Genghis Khan.
| Mozart still at piano.
Mozart | Bad luck Genghis. Nice to have you on the show. And now here are the scores.
| Scoreboard with Eddie Waring figure standing by it. The scoreboard looks a little like this:
St Stephan | 29.9
Richard III | 29.3
Jean D'arc | 29.1
Marat | 29.0
A. Lincoln (U.S of A) | 28.2
G. Khan | 28.1
King Edward VII | 3.1
Eddie | Well there you can see the scores now. St Stephen in the lead there with his stoning, then comes King Richard the Third at Bosworth Field, a grand death that, then the very lovely Jean d'Arc, then Marat in his bath - best of friends with Charlotte in the showers afterwards - then A. Lincoln of the U.S of A, a grand little chap that, and number six Genghis Khan, and the back marker King Edward the Seventh. Back to you, Wolfgang.
| Mozart still at piano.
Mozart | Thank you, Eddie. And now time for this week's request death. (taking card off piano) For Mr and Mrs Violet Stebbings of 23 Wolverston Road, Hull, the death of Mr Bruce Foster of Guildford.
| Cut to a lounge setting. Mr Foster sitting in chair.
Foster | Strewth! (he dies)
| Mozart still there. He looks at watch.
Mozart | Oh blimey, how time flies. Sadly we are reaching the end of yet another programme and so it is finale time. We are proud to be bringing to you one of the evergreen bucket kickers. Yes, the wonderful death of the famous English Admiral Nelson.
| Cut to a modern office block, as high as possible. After a pause a body flies out of the top window looking as much like Nelson as possible. As it plummets there is a strangled scream.
Nelson | Kiss me Hardy!
| The body hits the ground. There is the loud noise of a pig squealing. Cut to a night school Teacher looking down out of classroom window. He crosses to a long wall blackboard with line of pigs drawn on near end. He crosses one off, walks along blackboard to other end which has written on it 'evening classes 7-8 p.m.'. He writes 'Italian' below this and turns to camera.
Teacher | Ah - good evening everyone, and welcome to the second of our Italian language classes, in which we'll be helping you brush up your Italian. Last week we started at the beginning, and we learnt the Italian for a 'spoon'. Now, I wonder how many of you can remember what it was?
| Shout of 'Si! Si! Si!' from the class whom we see are all Italians.
Teacher | Not all at once ... sit down Mario. Giuseppe!
Giuseppe | Il cucchiaio.
Teacher | Well done Giuseppe, or, as the Italians would say: 'Molto bene, Giuseppe'.
Giuseppe | Grazie signor ... grazie di tutta la sua gentilezza.
Teacher | Well, now, this week we're going to learn some useful phrases to help us open a conversation with an Italian. Now first of all try telling him where you come from. For example, I would say: 'Sono Inglese di Gerrard's Cross', I am an Englishman from Gerrard's Cross. Shall we all try that together?
All | Sono Inglese di Gerrard's Cross.
Teacher | Not too bad, now let's try it with somebody else. Er... Mr... ?
Mariolini | Mariolini.
Teacher | Ah, Mr Mariolini, and where are you from?
Mariolini | Napoli, signor.
Teacher | Ah ... you're an Italian.
Mariolini | Si, si signor!
Teacher | Well in that case you would say: 'Sono Italiano di Napoli'.
Mariolini | Ah, capisco, mile grazie signor...
Francesco | Per favore, signor!
Teacher | Yes?
Francesco | Non conosgeve parliamente, signor devo me parlo sono Italiano di Napoli quando il habitare de Milano.
Teacher | I'm sorry ... I don't understand!
Giuseppe | (pointing to Francesco) My friend say 'Why must he say...'
| Hand goes up at back of room and a Lederhosen Teutonic figure stands up.
German | Bitte mein Herr. Was ist das Won für Mittelschmerz?
Teacher | Ah! Helmut - you want the German classes.
German | Oh ja! Danke schön. (he starts to leave) Ah das deutsche Klassenzimmer... Ach! (he leaves)
Giuseppe | My friend he say, 'Why must I say I am Italian from Napoli when he lives in Milan?'
Teacher | Ah, I... well, tell your friend ... if he lives in Milan he must say 'Sono Italiano di Milano...'
Francesco | (agitatedly, leaping to his feet) Eeeeeee! Milano è tanto meglio di Napoli. Milano è la citta la più bella di tutti ... nel mondo...
Giuseppe | He say 'Milan is better than Napoli'.
Teacher | Oh, he shouldn't be saying that, we haven't done comparatives yet.
| In the background everyone has started talking in agitated Italian. At this point a genuine mandolin-playing Italian secreted amongst the cast strikes up: 'Quando Caliente Del Sol...' or similar. The class is out of control by this time. The teacher helplessly tries to control then but eventually gives up and retreats to his desk and sits down. There is a loud pig squeal and he leaps up.
| ANIMATION:The Blackboard with the coloured pigs drawn on it, is reproduced on the first few frames of the animation film. A real hand comes into the picture and crosses off a third pig. Thereafter action follows the dictates of Señor Gilliam's wonderfully visual mind. At the end of this animation we have an advertisement for Whizzo butter.
Voice Over | (on animation) Yes, mothers, new improved Whizzo butter containing 10% more or less is absolutely indistinguishable from a dead crab. Remember, buy Whizzo butter and go to HEAVEN!
| Cut to a group middle-aged lower-middle-class women (hereinafter referred to as 'Pepperpots') being interviewed.
First Pepperpot | I can't tell the difference between Whizzo butter and this dead crab.
Interviewer | Yes, you know, we find that nine out of ten British housewives can't tell the difference between Whizzo butter and a dead crab.
Pepperpots | It's true, we can't. No.
Second Pepperpot | Here. Here! You're on television, aren't you?
Interviewer | (modestly) Yes, yes.
Second Pepperpot | He does the thing with one of those silly women who can't tell Whizzo butter from a dead crab.
Third Pepperpot | You try that around here, young man, and we'll slit your face.
| CAPTION: 'IT'S THE ARTS'
| Linkman sitting at desk
Linkman | Good evening and welcome to another edition of 'It's the Arts'. And we kick off this evening with the cinema.
| Cut to second interviewer an Ross.
Second Interviewer | Good evening. One of the most prolific film directors of this age, or indeed of any age, is Sir Edward Ross, back in his native country for the first time for five years to open a season of his works at the National Film Theatre, and we are very fortunate to have him with us in this studio this evening.
Ross | Good evening.
Second Interviewer | Edward... you don't mind if I call you Edward?
Ross | No, not at all.
Second Interviewer | Only it does worry some people - I don't know why...but they are a little sensitive so I take the precaution of asking on these occasions.
Ross | No, no, no that's fine.
Second Interviewer | So Edward's all right. Splendid. Splendid. I'm sorry to have brought it up, only eh...
Ross | No, no, please. Edward it is.
Second Interviewer | Well thank you very much for being so helpful...only it's more than my job's worth to...er...
Ross | Quite, yes.
Second Interviewer | Makes it rather difficult to establish a rapport ... to put the other person at his ease...
Ross | Quite.
Second Interviewer | Yes, silly little point but it does seem to matter. Still - less said the better. Uh...Ted...when you first started in...you don't mind if I call you Ted?
Ross | No, no, no everyone calls me Ted.
Second Interviewer | Well it's shorter, isn't it.
Ross | Yes it is.
Second Interviewer | Yes, and much less formal!
Ross | Yes, Ted, Edward, anything!
Second Interviewer | Splendid, splendid. Incidentally, do call me Tom, I don't want you playing around with any of this 'Thomas' nonsense! Ha ha ha ha! Now where were we? Ah yes. Eddie-baby, when you first started in the...
Ross | I'm sorry, I'm sorry, but I don't like being called 'Eddie-baby'.
Second Interviewer | I'm sorry?
Ross | I don't like being called 'Eddie-baby'.
Second Interviewer | Did I call you 'Eddie-baby'?
Ross | Yes, you did! Now get on with it.
Second Interviewer | I don't think I did call you Eddie-baby.
Ross | You did call me Eddie-baby.
Second Interviewer | (looking off-screen) Did I call him Eddie-baby?
Voices | Yes. No. Yes.
Second Interviewer | I didn't really call you Eddie-baby, did I, sweetie?
Ross | Don't call me sweetie!!
Second Interviewer | Can I call you sugar plum?
Ross | No!
Second Interviewer | Pussy cat?
Ross | No.
Second Interviewer | Angel-drawers?
Ross | No you may not! Now get on with it!
Second Interviewer | Can I call you 'Frank'?
Ross | Why Frank?
Second Interviewer | It's a nice name. Robin Day's got a hedgehog called Frank.
Ross | What is going on?
Second Interviewer | Frannie, little Frannie, Frannie Knickers...
Ross | (Getting up) No. I'm leaving. I'm leaving. I'm off...
Second Interviewer | Tell us about your latest film, Sir Edward.
Ross | (Off-screen) What?
Second Interviewer | Tell us about your latest film, if you'd be so very kind, Sir Edward.
Ross | None of this 'pussy cat' nonsense?
Second Interviewer | Promise. (Pats seat) Please, Sir Edward.
Ross | My latest film?
Second Interviewer | Yes, Sir Edward.
Ross | Well the idea, funnily enough, came from an idea I had when I first joined the industry in 1919. Of course, in those days I was only the tea boy.
Second Interviewer | Oh, shut up.
| Cut to linkman, as before
Linkman | Sir Edward...Ross. Now, later in the programme we will be bringing you a unique event in the world of modern art. Pablo Picasso will be doing a special painting for us, on this programme, live, on a bicycle. But right now it's time to look at a man whose meteoric rise to fame...
| A pig squeals. Interviewer leaps up, grabs a revolver from his desk drawer and fires off-screen. CAPTION: 'PIGS 3, NELSON 1' Third Interviewer and Arthur 'Two Sheds' Jackson. Musical score blow-up behind.
Third Interviewer | Last week the Royal Festival Hall saw the first performance of a new symphony by one of the world's leading modern composers, Arthur 'Two Sheds' Jackson. Mr Jackson.
Jackson | Good evening.
Third Interviewer | May I just sidetrack for one moment. Mr. Jackson, this, what shall I call it, nickname of yours.
Jackson | Ah yes.
Third Interviewer | 'Two sheds'. How did you come by it?
Jackson | Well, I don't use it myself, it's just a few of my friends call me 'Two Sheds'.
Third Interviewer | I see, and do you in fact have two sheds?
Jackson | No. No, I've only one shed. I've had one for some time, but a few years ago I said I was thinking of getting another one, and since then some people have called me 'Two Sheds'.
Third Interviewer | In spite of the fact that you only have one.
Jackson | Yes.
Third Interviewer | I see, and are you thinking of purchasing a second shed?
Jackson | No!
Third Interviewer | To bring you in line with your epithet?
Jackson | No.
Third Interviewer | I see, I see. Well let's return to your symphony. Ah, now then, did you write this symphony...in the shed?
Jackson | No!
Third Interviewer | Have you written any of your recent works in this shed of yours?
Jackson | No it's just a perfectly ordinary garden shed.
| A picture of a shed appears on the screen behind them.
Third Interviewer | I see. And you're thinking of buying this second shed to write in.
Jackson | No, no. Look. This shed business, it doesn't really matter at all, the sheds aren't important. It's just a few friends call me Two Sheds and that's all there is to it. I wish you'd ask me about my music. I'm a composer. People always ask me about the sheds, they've got it out of proportion, I'm fed up with the shed, I wish I'd never got it in the first place.
Third Interviewer | I expect you are probably thinking of selling one.
Jackson | I will sell one.
Third Interviewer | Then you'll be Arthur 'No Sheds' Jackson?
Jackson | Look, forget about the sheds. They don't matter.
Third Interviewer | Mr. Jackson, I think, with respect, we ought to talk about your symphony.
Jackson | What?
Third Interviewer | Apparently your symphony was written for organ and tympani.
Jackson | (catches sight of the picture of the shed behind hin) What's that?
Third Interviewer | What's what?
Jackson | It's a shed. Get it off.
| He points to BP screen shed. The picture of the shed disappears and is replaced by a picture of Jackson. Jackson looks at it carefully.
Jackson | Right.
Third Interviewer | Now then Mr. Jackson...your symphony.
| CAPTION: 'ARTHUR "TWO SHEDS" JACKSON' Cut back to studio: the picture of him is replaced by a picture of two sheds, one with a question mark over it.
Third Interviewer | I understand that you used to be interested in train-spotting.
Jackson | What?
Third Interviewer | I understand that, about thirty years ago, you were extremely interested in train-spotting.
Jackson | What's that got to do with my bloody music?
| Enter Second Interviewer from Edward Ross sketch (John)
Second Interviewer | Are you having any trouble from him?
Third Interviewer | Yes, a little.
Second Interviewer | Exactly. Well we interviewers are more than a match for the likes of you, 'Two Sheds'.
Third Interviewer | Yes, make yourself scarce, 'Two Sheds'. This studio isn't big enough for the three of us!
| They push him away and propel him out.
Jackson | What are you doing? (he is pushed out of vision with a crash)
Second Interviewer | Get your own Arts programme, you fairy!
Third Interviewer | (to camera) Arthur 'Two Sheds' Jackson.
| Cut to linkman. He is about to speak when:
Third Interviewer | (off-screen) Never mind, Timmy.
Second Interviewer | (off-screen) Oh, Michael, you are such a comfort.
Linkman | Arthur 'Two Sheds'...
| Cut to a man in Viking helmet at desk.
Viking | ...Jackson.
| Cut back to linkman.
Linkman | And now for more news of the momentous artistic event in which Pablo Picasso is doing a specially commissioned painting for us whilst riding a bicycle. Pablo Picasso - the founder of modern art - without doubt the greatest abstract painter ever... for the first time painting in motion. But first of all let's have a look at the route he'll be taking.
| Cut to Raymond Baxter type standing in front of map. A small cardboard cut-out of Picasso's face is on map and is moved around to illustrate route.
Baxter | Well Picasso will be starting, David, at Chichester here, he'll then cycle on the A29 to Fontwell, he'll then take the A272 which will bring him on to the A3 just north of Hindhead here. From then on Pablo has a straight run on the A3 until he meets the South Circular at Battersea here. Well, this is a truly remarkable occasion as it is the first time that a modern artist of such stature has taken the A272, and it'll be very interesting to see how he copes with the heavy traffic round Wisborough Green. Vicky.
| Cut to Vicky, holding a bicycle.
Vicky | Well Picasso will be riding his Viking Super Roadster with the drop handlebars and the dual-thread wheel-rims and with his Wiley-Prat 20-1 synchro-mesh he should experience difficulties on the sort of road surfaces they just don't get abroad. Mitzie.
| Cut to linkman at desk with Viking on one side and a knight in armour on the other.
Linkman | And now for the latest report on Picasso's progress over to Reg Moss on the Guildford by-pass.
| Reg Moss standing with hand mike by fairly busy road.
Reg Moss | Well there's no sign of Picasso at the moment, David. But he should be through here at any moment. However I do have with me Mr Ron Geppo, British Cycling Sprint Champion and this year's winner of the Derby-Doncaster rally.
| Geppo is in full cyclist's kit.
Geppo | Well Reg, I think Pablo should be all right provided he doesn't attempt anything on the monumental scale of some of his earlier paintings, like Guernica or Mademoiselles d'Avignon or even his later War and Peace murals for the Temple of Peace chapel at Vallauris, because with this strong head wind I don't think even Doug Timpson of Manchester Harriers could paint anything on that kind of scale.
Reg Moss | Well, thank you Ron. Well, there still seems to be no sign of Picasso, so I'll hand you back to the studio.
Linkman | Well, we've just heard that Picasso is approaching the Tolworth roundabout on the A3 so come in Sam Trench at Tolworth.
| Cut to Sam Trench at roadside.
Trench | Well something certainly is happening here at Tolworth roundabout, David. I can now see Picasso, he's cycling down very hard towards the roundabout, he's about 75-50 yards away and I can now see his painting... it's an abstract... I can see some blue some purple and some little black oval shapes... I think I can see...
| A Pepperpot comes up and nudges him.
Pepperpot | That's not Picasso - that's Kandinsky.
Trench | (excited) Good lord, you're right. It's Kandinsky. Wassily Kandinsky, and who's this here with him? It's Braque. Georges Braque, the Cubist, painting a bird in flight over a cornfield and going very fast down the hill towards Kingston and... (cylists pass in front of him) Piet Mondrian - just behind, Piet Mondrian the Neo-Plasticist, and then a gap, then the main bunch, here they come, Chagall, Max Ernst, Miro, Dufy, Ben Nicholson, Jackson Pollock and Bernard Buffet making a break on the outside here, Brancusi's going with him, so is Gericault, Ferdinand Leger, Delaunay, De Kooning, Kokoschka's dropping back here by the look of it, and so's Paul Klee dropping back a bit and, right at the back of this group, our very own Kurt Schwitters..
Pepperpot | He's German!
Trench | But as yet absolutely no sign of Pablo Picasso, and so from Tolworth roundabout back to the studio.
| Toulouse-Lautrec pedals past on a child's tricycle. Cut back to studio.
Linkman | Well I think I can help you there Sam, we're getting reports in from the AA that Picasso, Picasso has fallen off...he's fallen off his bicycle on the B2127 just outside Ewhurst, trying to get a short cut through to Dorking via Gomslake and Peashall. Well, Picasso is reported to be unhurt, but the pig has a slight headache. And on that note we must say goodnight to you. Picasso has failed in his first bid for international cycling fame. So from all of us here at the 'It's the Arts' studio, it's goodnight. Goodnight. (pigs head appears over edge of desk; linkman gently pushes it back)
| ANIMATION: Cartoon sequence of animated Victorian photos, at the end of which a large pig descends, fatally, on a portrait of a man. Cut to wartime planning room. Two officers are pushing model pigs across the map. A private enters and salutes.
Private | Dobson's bought it, sir.
Officer | Porker, eh? Swine.
| Cut to a suburban house in a rather drab street. Zoom into upstairs window. Seriuos documentary music. Interior of a small room. A bent figure (Michael) huddles over a table, writing. He is surrounded by bits of paper. The camera is situated facing the man as he writes with immense concentration lining his unshaven face.
Voice Over | This man is Ernest Scribbler... writer of jokes. In a few moments, he will have written the funniest joke in the world... and, as a consequence, he will die ... laughing.
| Ernest stops writing, pauses to look at what he has written... a smile slowly spreads across his face, turning very, very slowly to uncontrolled hysterical laughter... he staggers to his feet and reels across room helpless with mounting mirth and eventually collapses and dies on the floor.
Voice Over | It was obvious that this joke was lethal... no one could read it and live ...
| The scribbler's mother (Eric) enters. She sees him dead, she gives a little cry of horror and bends over his body, weeping. Brokenly she notices the piece of paper in his hand and (thinking it is a suicide note - for he has not been doing well for the last thirteen years) picks it up and reads it between her sobs. Immediately she breaks out into hysterical laughter, leaps three feet into the air, and falls down dead without more ado. Cut to news type shot of commentator standing in front of the house.
Commentator | (reverentially) This morning, shortly after eleven o'clock, comedy struck this little house in Dibley Road. Sudden ...violent ... comedy. Police have sealed off the area, and Scotland Yard's crack inspector is with me now.
Inspector | I shall enter the house and attempt to remove the joke.
| At this point an upstairs window in the house is flung open and a doctor, with stetoscope, rears his head out, hysterical with laughter, and dies hanging over the window sill. The commentator and the inspector look up briefly and sadly, and then continue as if they are used to such sights this morning.
Inspector | I shall be aided by the sound of sombre music, played on gramophone records, and also by the chanting of laments by the men of Q Division ... (he indicates a little knot of dour-looking policemen standing nearby) The atmosphere thus created should protect me in the eventuality of me reading the joke.
| He gives a signal. The group of policemen start groaning and chanting biblical laments. The Dead March is heard. The inspector squares his shoulders and bravely starts walking into the house.
Commentator | There goes a brave man. Whether he comes out alive or not, this will surely be remembered as one of the most courageous and gallant acts in police history.
| The inspector suddenly appears at the door, helpless with laughter, holding the joke aloft. He collapses and dies. Cut to film of army vans driving along dark roads.
Voice Over | It was not long before the Army became interested in the military potential of the Killer Joke. Under top security, the joke was hurried to a meeting of Allied Commanders at the Ministry of War.
| Cut to door at Ham House: Soldier on guard comes to attention as dispatch rider hurries in carrying armoured box. (Notice on door: 'Conference. No Admittance'.) Dispatch nider rushes in. A door opens for him and closes behind him. We hear a mighty roar of laughter... . series of doomphs as the commanders hit the floor or table. Soldier outside does not move a muscle. Cut to a pillbox on the Salisbury Plain. Track in to slit to see moustachioed top brass peering anxiously out.
Voice Over | Top brass were impressed. Tests on Salisbury Plain confirmed the joke's devastating effectiveness at a range of up to fifty yards.
| Cut to shot looking out of slit in pillbox. Zoom through slit to distance where a solitary figure is standing on the windswept plain. He is a bespectacled, weedy lance-corporal (Terry Jones) looking cold and miserable. Pan across to fifty yards away where two helmeted soldiers are at their positions beside a blackboard on an easel covered with a cloth. Cut in to corporal's face - registening complete lack of comprehension as well as stupidity. Man on top of pillbox waves flag. The soldiers reveal the joke to the corporal. He peers at it, thinks about its meaning, sniggers, and dies. Two watching generals are very impressed.
Generals | Fantastic.
| Cut to a Colonel talking to camera.
Colonel | All through the winter of '43 we had translators working, in joke-proof conditions, to try and produce a German version of the joke. They worked on one word each for greater safety. One of them saw two words of the joke and spent several weeks in hospital. But apart from that things went pretty quickly, and we soon had the joke by January, in a form which our troops couldn't understand but which the Germans could.
| Cut to a trench in the Ardennes. Members of the joke brigade are crouched holding pieces of paper with the joke on them.
Voice Over | So, on July 8th, 1944, the joke was first told to the enemy in the Ardennes...
Commanding NCO | Tell the ... joke.
Joke Brigade | (together) Wenn ist das Nunstruck git und Slotermeyer? Ja! ... Beiherhund das Oder die Flipperwaldt gersput!
| Pan out of the British trench across war-torn landscape and come to rest where presumably the German trench is. There is a pause and then a group of Germans rear up in hysterics.
Voice Over | It was a fantastic success. Over sixty thousand times as powerful as Britain's great pre-war joke ...
| Cut to a film of Chamberlain brandishing the 'Peace in our time' bit of paper.
Voice Over | ...and one which Hitler just couldn't match.
| Film of Hitler rally. Hitler speaks; subtitles are superimposed. SUBTITLE 'MY DOG'S GOT NO NOSE' A young soldier responds: SUBTITLE: HOW DOES HE SMELL? Hitler speaks: SUBTITLE: AWFUL'
Voice Over | In action it was deadly.
| Cut to a small squad with rifles making their way through forest. Suddenly one of them (a member of the joke squad) sees something and gives signal at which they all dive for cover. From the cover of a tree he reads out joke.
Joke Corporal | Wenn ist das Nunstruck git und Slotermeyer? Ja! .. Beiherhund das Oder die Flipperwaldt gersput!
| Sniper falls laughing out of tree.
Joke Brigade | (charging) Wenn ist das Nunstruck git und Slotermeyer? Ja! ... Beiherhund das Oder die Flipperwaldt gersput.
| They chant the joke. Germans are put to flight laughing, some dropping to ground.
Voice Over | The German casualties were appalling.
| Cut to a German hospital and a ward full of casualties still laughing hysterically. Cut to Nazi interrogation room. An officer from the joke brigade has a light shining in his face. A Gestapo officer is interrogating him; another (clearly labelled 'A Gestapo Officer') stands behind him.
Nazi | Vott is the big joke?
Officer | I can only give you name, rank, and why did the chicken cross the road?
Nazi | That's not funny! (slaps him) I vant to know the joke.
Officer | All right. How do you make a Nazi cross?
Nazi | (momentarily fooled) I don't know ... how do you make a Nazi cross?
Officer | Tread on his corns. (does so; the Nazi hops in pain)
Nazi | Gott in Himmel! That's not funny! (mimes cuffing him while the other Nazi claps his hands to provide the sound effct) Now if you don't tell me the joke, I shall hit you properly.
Officer | I can stand physical pain, you know.
Nazi | Ah ... you're no fun. All right, Otto.
| Otto (Graham) starts tickling the officer who starts laughing.
Officer | Oh no - anything but that please no, all right I'll tell you.
| They stop.
Nazi | Quick Otto. The typewriter.
| Otto goes to the typewriter and they wait expectantly. The officer produces piece of paper out of his breast pocket and reads.
Officer | Wenn ist das Nunstruck git und Slotermeyer? Ja! ... Beiherhund das Oder die Flipperwaldt gersput.
| Otto at the typewriter explodes with laughter and dies.
Nazi | Ach! Zat iss not funny!
| Bursts into laughter and dies. A guard (Terry G) bursts in with machine gun, The British officer leaps on the table.
Officer | (lightning speed) Wenn ist das Nunstruck git und Slotermeyer? Ja! ... Beiherhund das Oder die Flipperwaldt gersput.
| The guard reels back and collapses laughing. British officer makes his escape. Cut to stock film of German scientists working in laboratories.
Voice Over | But at Peenemunde in the Autumn of '44, the Germans were working on a joke of their own.
| Cut to interior. A German general (Terry J) is seated at an imposing desk. Behind him stands Otto, labelled 'A Different Gestapo Officer'. Bespectacled German scientist/joke writer enters room. He clean his throat and reads from card.
German Joker | Die ist ein Kinnerhunder und zwei Mackel über und der bitte schön ist den Wunderhaus sprechensie. 'Nein' sprecht der Herren 'Ist aufern borger mit zveitingen'.
| He finishes and looks hopeful.
Otto | We let you know.
| He shoots him. More stock film of German scientists.
Voice Over | But by December their joke was ready, and Hitler gave the order for the German V-Joke to be broadcast in English.
| Cut to 1940's wartime radio set with couple anxiously listening to it.
Radio | (crackly German voice) Der ver zwei peanuts, valking down der strasse, and von vas... assaulted! peanut. Ho-ho-ho-ho.
| Radio bursts into 'Deutschland Über Alles'. The couple look at each other and then in blank amazement at the radio. Cut to modern BBC 2 interview. The commentator in a woodland glade.
Commentator | In 1945 Peace broke out. It was the end of the Joke. Joke warfare was banned at a special session of the Geneva Convention, and in 1950 the last remaining copy of the joke was laid to rest here in the Berkshire countryside, never to be told again.
| He walks away revealing a monument on which is written: 'To the unknown Joke'. Camera pulls away slowly through idyllic setting. Patriotic music reaches cresendo. Cut to football referee who blows whistle. Silence. Blank screen. CAPTION: 'THE END' The seashore again, with the 'It's' man lying on the beach. A stick from off-screen prods him. Exhausted, he rises and staggers back into the sea. CAPTION: '"WHITHER CANADA" WAS CONCIEVED WRITTEN AND PERFORMED BY...(CREDITS)
Announcer | And here is the final score: Pigs 9 - British Bipeds 4. The Pigs go on to meet Vicki Carr in the final.